@@ -185,17 +185,17 @@ sub _read {
   until ($self->is_finished) {
 
     # Preamble
-    if ($self->{multi_state} ~~ 'multipart_preamble') {
+    if (($self->{multi_state} // '') eq 'multipart_preamble') {
       last unless $self->_parse_multipart_preamble($boundary);
     }
 
     # Boundary
-    elsif ($self->{multi_state} ~~ 'multipart_boundary') {
+    elsif (($self->{multi_state} // '') eq 'multipart_boundary') {
       last unless $self->_parse_multipart_boundary($boundary);
     }
 
     # Body
-    elsif ($self->{multi_state} ~~ 'multipart_body') {
+    elsif (($self->{multi_state} // '') eq 'multipart_body') {
       last unless $self->_parse_multipart_body($boundary);
     }
   }
